@@ -1,30 +1,27 @@
 use std::path::PathBuf;
 
 use anyhow::{bail, Result};
-use inflections::case::is_kebab_case;
 
+use crate::api;
 use crate::config::{update_config, CONFIG_PATH};
-use crate::consts::BASE_DIR;
+use crate::template::{self, article_file_path};
+use crate::validator;
 
 pub(crate) fn exec(title: &String, devto_token: String) -> Result<()> {
-    if !is_kebab_case(title) {
-        bail!("Title must be in kebab-case");
-    }
+    validator::basic(title)?;
 
-    let article_file: PathBuf = [BASE_DIR, title, format!("{}.md", title).as_str()]
-        .iter()
-        .collect();
+    let article_file: PathBuf = article_file_path(title);
     if article_file.exists() {
         bail!("Article already exists");
     }
 
-    let article_id = crate::api::create_draft(title, devto_token)?;
+    let article_id = api::create_draft(title, devto_token)?;
     println!("Created an article with id: {article_id}");
 
     update_config(article_id, article_file.clone())?;
     println!("Updated config file: {CONFIG_PATH}");
 
-    crate::template::generate(title, article_file.clone())?;
+    template::generate(title, article_file.clone())?;
     println!("Generated template file: {:?}", article_file);
 
     Ok(())
