@@ -14,8 +14,11 @@ pub(crate) struct Config {
     pub(crate) relative_path_to_article: String,
 }
 
-fn write_config(config: Vec<Config>) -> Result<()> {
-    let file = OpenOptions::new().write(true).open(CONFIG_PATH)?;
+pub(crate) fn write_config(config: Vec<Config>) -> Result<()> {
+    let file = OpenOptions::new()
+        .write(true)
+        .truncate(true)
+        .open(CONFIG_PATH)?;
     let mut writer = BufWriter::new(file);
 
     serde_json::to_writer_pretty(&mut writer, &config)?;
@@ -40,3 +43,9 @@ pub(crate) fn update_config(article_id: u32, article_file: PathBuf) -> Result<()
     write_config(config)?;
     Ok(())
 }
+
+pub(crate) fn get_article_index(config: &[Config], article_file: String) -> Option<usize> {
+    config
+        .iter()
+        .position(|x| x.relative_path_to_article == article_file)
+}
