@@ -4,6 +4,14 @@ use std::path::PathBuf;
 
 use anyhow::Result;
 
+use crate::consts::BASE_DIR;
+
+pub(crate) fn article_file_path(title: &String) -> PathBuf {
+    [".", BASE_DIR, title, format!("{}.md", title).as_str()]
+        .iter()
+        .collect()
+}
+
 pub(crate) fn generate(title: &String, article_file: PathBuf) -> Result<()> {
     fs::create_dir_all(article_file.parent().unwrap())?;
 
